/**
 * FAQ eample for in block preview pane.
 *
 * @type {Object}
 */
export default {
	attributes: {
		questions: [
			{
				visible: true,
				titleWrapper: 'div',
				title: 'Question',
				content:
					'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
			},
		],
	},
}
